function Iout = ManualTrackingToTableGJB1(Tracks)

%Input: the imported csv tracks file (import as array) from the
%ImageJ Manual Tracking plugin. Tracks = matrix with trajectory numbers, frame-
%numbers, x, y, distance, velocity and pixel intensity. 
%Processing: intensity values in traces are replaced with values  found
%at the same locations (x,y,t) in an image stack opened from the
%workspace. This image stack is the imageJ-filtered raw image stack. 
%Output: array, with the intensity time traces of each track within columns.

%Parts taken from IntensityTimetracesGJB2
%(exosome time traces addition from thesis tracking analysis) and ProcesstracesGJB1.

imagefile='seq5_opa50_00001greenTimes10Mean2.tif';
lastimage=425;

%%% Rearrange Tracks from Fiji Manual TRacking tool to use with old code below
r=size(Tracks,1);
pixelsize=1 % µm/pixel, in case the positions are given in µm's, it can be converted backwards to pixels. This is needed for the analysis program. 
TRtotal=[Tracks(:,3)./pixelsize, Tracks(:,4)./pixelsize, 100.*ones(r,4), Tracks(:,2), Tracks(:,1)]; %, T.*ones(r,1), movienr.*ones(r,1) %TRtemp=

  
%%% -----------Generate intensity time traces part -----------------------------------------
r=size(TRtotal,1);
rr=size(TRtotal,2);
Itotal=zeros((lastimage+1),1,3);
% New structure of the data: each column is a trajectory. Rows first dimension:
% directory, movienr, trajectory nr, frame rate, start frame, first x, first y, intensities.
% Second and third dimension: x and y positions.

u=0;
LastTrajNr=TRtotal(r,8);
for j=1:LastTrajNr % check all trajectory numbers, if they are in the dataset
    tracenr=j;
    trace=zeros(1,rr);
    
    s=0;
    for i=1:r
        if TRtotal(i,8)==tracenr % replace zero vector 'trace' if the trajectory number 'tracenr' is present in the TR dataset.
            trace(s+1,:)=TRtotal(i,:);
            s=s+1;
        end
    end
        
    %modify trajectories 
    
    if trace(1,:)~=zeros(1,rr) % only process trajectory if 'trace' is not just a zero vector.
        u=u+1;
        tracelength=size(trace,1);
        traceStart=trace(1,7);
        traceEnd=trace(tracelength,7);
        
        newlength=lastimage;
        newtrace=zeros(newlength,rr);
        newtrace(:,1)=ones(newlength,1).*trace(tracelength,1);%newtrace((tracelength+1):newlength,1)=ones((newlength-tracelength),1)
        newtrace(:,2)=ones(newlength,1).*trace(tracelength,2);%newtrace((tracelength+1):newlength,2)=ones((newlength-tracelength),1)
        newtrace(traceStart,:)=trace(1,:);
        w=1;
        for i=1:tracelength-1 % replace zeros and fixed x,y values in newtrace for trace values
            if trace(i,7)==( trace(i+1,7)-1 ) % no frame skipped in trace?
                newtrace((traceStart+w),:)=trace((i+1),:); % replace zero values
                w=w+1; % add one to index of newtrace
            end
        end
        Itotal(1,u,1)=trace(1,8); %trajectory nr (3rd row)
        Itotal(2,u,1)=traceStart;
        Itotal(3,u,1)=traceEnd;
        Itotal(4:5,u,1)=newtrace(traceStart,1:2); %x and y (4th and 5th row, from first timepoint where spot was detected)
        Itotal(6:(newlength+5),u,2:3)=newtrace(:,1:2); % x,y
    end %modify trajectory to include
end


% substitute zeros in intensity traces before first traced frame and after last traced frame 
% by intensity values found at the different time points, at the positions
% of the first and last frame.

ImageSize=size(imread(imagefile,1),1);
N=zeros(ImageSize,ImageSize,lastimage);
for j=1:lastimage
    N(:,:,j)=imread(imagefile,j); %[Dir '\' Filename Extension]
end

NrTraj=size(Itotal,2);
for j=1:lastimage
    for i=1:NrTraj
        Itotal((j+5),i,1)=N(Itotal((j+5),i,3)+1,Itotal((j+5),i,2)+1,j);
    end
%     a=N(:,:,j);
%     imagesc(a)
%     axis image
%     hold on
%     plot(Itotal((1+j),:,2),Itotal((1+j),:,3), 'o', 'MarkerEdgeColor','r', 'MarkerSize',15,'LineWidth',2)% Somehow the axis x and y are reversed in the image
%     hold off
%     pause
end 

    
Iout=Itotal;%(:,:,1);